var internalRadioTypeSelect = null;

function initRadio()
{
	// Define the callbacks for the asyncRequest
	var callbacks = {
		
		success : function (o) {

			YAHOO.log("RAW JSON DATA: " + o.responseText);

			// Process the JSON data returned from the server
			var data;
			try {
				data = YAHOO.lang.JSON.parse(o.responseText);
			}
			catch (x) {
				YAHOO.log("ERROR: JSON Parse failed!");

				// Retry
				setTimeout("initRadio()", 5000);

				return;
			}

			YAHOO.log("PARSED DATA: " + YAHOO.lang.dump(data));

			// Get config
			var config = data.ConfigRadio;
			if (config == null) return;
			
			// -- Mode --
			setFieldValue('Radio-Field-Mode', config.Mode);
			//setItemDisplayed('Radio-Group-Internal-Sensitivity', true );//config.Mode == 1 /* Rover */);
			
			// Get Internal config
			var internal = config.InternalRadio;
			if (internal == null) return;

			// -- Internal Power --
			checkRadioButton(
				new Array(
					'Radio-Field-Internal-Power-On', 
					'Radio-Field-Internal-Power-Off'), internal.Power);
			
			// -- Internal Power Mode --
			checkRadioButton(
				new Array(
					'Radio-Field-Internal-PowerMode-Auto', 
					'Radio-Field-Internal-PowerMode-Manual'), internal.PowerManagement);

			// -- Internal Radio Type -- 
			setFieldValue('Radio-Field-Internal-RadioType', internal.RadioType);
			enableField('Radio-Field-Internal-RadioType', false);
			enableInternalRadioParameters(internal.RadioType);
			
			// -- Show only current radio type --
			if (internalRadioTypeSelect == null) internalRadioTypeSelect = new SelectFieldManager('Radio-Field-Internal-RadioType');
			internalRadioTypeSelect.setFieldOptions([internal.RadioType]);

			// -- Internal Frequencies --
			if (internal.ChannelTable.length > 0)
			{
				clearAllFieldOptions('Radio-Field-Internal-ChannelNumber');
				for (ch in internal.ChannelTable)
				{
					var channel = internal.ChannelTable[ch];
					addFieldOption('Radio-Field-Internal-ChannelNumber', formatChannel(channel), channel.ChannelIndex);
				}
				setFieldValue('Radio-Field-Internal-ChannelNumber', internal.ChannelNumber);
			}
			else
			{
				setFieldValue('Radio-Field-Internal-ChannelNumber', 255);
			}

			// -- Internal Parameters --
			setFieldValue('Radio-Field-Internal-Protocol', internal.Protocol);
			setFieldValue('Radio-Field-Internal-AirLinkSpeed', internal.AirLinkSpeed);
			setFieldValue('Radio-Field-Internal-Sensitivity', internal.Sensitivity);
						
			//Status	
			setFieldChecked( 'Radio-Field-Internal-Scrambler', internal.Scrambler);
			setFieldChecked( 'Radio-Field-Internal-FEC', internal.FEC);

			setInternalAirLinkSpeed( internal.Protocol );
			
			// Get External config
			var external = config.ExternalRadio;
			if (external == null) return;

			processRadioTransmitter( external );

			// Show form
			showConfigForm();
		},

		failure : function (o) {
			if (!YAHOO.util.Connect.isCallInProgress(o)) {
				YAHOO.log("ERROR: Async call failed!");
			}
			
			// Retry
			setTimeout("initRadio()", 5000);
		},

		timeout : 10000,
		cache : false
    };

	// Make the call to the server for JSON data
	YAHOO.util.Connect.asyncRequest('GET', getConfigRadioURL, callbacks);

	setRadioTransmitterListeners();
	// External Radio Type changed
	YAHOO.util.Event.addListener( 'Radio-Field-Internal-RadioType', 'change', onInternalRadioTypeChange );
	YAHOO.util.Event.addListener( 'Radio-Field-Internal-Protocol', 'change', onInternalRadioProtocolChange );
}

var internalProtocolSelect = null;
var internalAirlinkSpeedSelect = null;

function enableInternalRadioParameters(type)
{
	// Init select managers
	if (internalProtocolSelect == null) internalProtocolSelect = new SelectFieldManager('Radio-Field-Internal-Protocol');
	if (internalAirlinkSpeedSelect == null) internalAirlinkSpeedSelect = new SelectFieldManager('Radio-Field-Internal-AirLinkSpeed');

	// Filter on select fields
	switch (eval(type))
	{
		case 2: // MDL
			internalProtocolSelect.setFieldOptions([0,2]); // Transparent, Dsnp
			internalAirlinkSpeedSelect.setFieldOptions([4,16,5]); // 4800, 7600, 9600
			break;
			
		case 4: // PDL
			internalAirlinkSpeedSelect.setFieldOptions([4,5,6]); // 4800, 9600, 19200
			internalProtocolSelect.setFieldOptions([0,1,2]); // Transparent, Trimtalk, Dsnp
			break;
	}
	
	// Parameters
	setItemDisplayed('Radio-Group-Internal-RadioParameters', 
		type == 2 /* MDL */ ||
		type == 4 /* PDL */);

	// No radio?
	setFieldVisible('Radio-Field-Internal-ChannelNumber', type > 0);
	setItemDisplayed('Radio-Group-Internal-Power', type > 0);
	setItemVisible('Radio-Button-Internal-LoadSettings', type > 0);
	setFieldVisible('Radio-Field-Internal-Sensitivity', type>0);
	
	//Scrambler + FEC
	setFieldVisible('Radio-Field-Internal-Scrambler', type == 4);
	setFieldVisible('Radio-Field-Internal-FEC', type == 4);
}

function onInternalRadioTypeChange(ev)
{
	var field = YAHOO.util.Event.getTarget(ev);
	
	enableInternalRadioParameters(field.value);
}

function onInternalRadioProtocolChange( event )
{
	var field = YAHOO.util.Event.getTarget(event);
	setInternalAirLinkSpeed( field.value );
}

function setInternalAirLinkSpeed( protocol )
{
	if ( protocol == '2' )//DSNP
	{
		if (internalAirlinkSpeedSelect == null) internalAirlinkSpeedSelect = new SelectFieldManager('Radio-Field-Internal-AirLinkSpeed');
		internalAirlinkSpeedSelect.setFieldOptions([4]);
	}
	else
	{
		enableInternalRadioParameters( getFieldValue( 'Radio-Field-Internal-RadioType' ) );
	}
}

function enableSerialPortOption( prefix, value )
{
	setItemDisplayed(prefix + '-Group-External-SerialPort', value > 0); 
}