function getRadioPrefixName()
{
	return YAHOO.util.Dom.get('TransmitterRadio-PagePrefix').value;
}

function processRadioTransmitter( config )
{
	var prefixName = getRadioPrefixName();
	
	setFieldValue( prefixName + '-Field-External-SerialPort', config.SerialPort);
	setSerialPortOptions( config.SerialPort );
	
	setFieldValue( prefixName + '-Field-External-SerialBaudRate', config.SerialBaudRate);
	setFieldChecked( prefixName + '-Field-External-SerialRtsCts', config.SerialRtsCts);
	setFieldValue( prefixName + '-Field-External-SerialMode', config.SerialMode);
	setOutputMode();	
	// -- External Radio Type -- 
	setFieldValue( prefixName + '-Field-External-RadioType', config.RadioType);
	enableExternalRadioParameters(config.RadioType, true);

	setExternalAirLinkSpeed( config.Protocol );
	
	// -- External Frequencies --
	if (config.ChannelTable.length > 0)
	{
		clearAllFieldOptions( prefixName + '-Field-External-ChannelNumber');
		for (ch in config.ChannelTable)
		{
			var channel = config.ChannelTable[ch];
			addFieldOption( prefixName + '-Field-External-ChannelNumber', formatChannel(channel), channel.ChannelIndex);
		}
		setFieldValue( prefixName + '-Field-External-ChannelNumber', config.ChannelNumber);
	}
	else
	{
		setFieldValue( prefixName + '-Field-External-ChannelNumber', 255);
	}

	// -- External Parameters --
	setFieldValue( prefixName + '-Field-External-Protocol', config.Protocol);
	setFieldValue( prefixName + '-Field-External-AirLinkSpeed', config.AirLinkSpeed);
	
	//Status	
	setFieldChecked( prefixName + '-Field-External-Scrambler', config.Scrambler);
	setFieldChecked( prefixName + '-Field-External-FEC', config.FEC);
}

function setRadioTransmitterListeners()
{
	var prefixName = getRadioPrefixName();
	
	// External Radio Type changed
	YAHOO.util.Event.addListener( prefixName + '-Field-External-RadioType', 'change', onExternalRadioTypeChange);
	
	// External Serial Port changed
	YAHOO.util.Event.addListener( prefixName + '-Field-External-SerialPort', 'change', onExternalSerialPortChange);
	
	// External Serial Mode changed
	YAHOO.util.Event.addListener( prefixName + '-Field-External-SerialMode', 'change', onExternalSerialModeChange);
	
	// Load radio settings click
	YAHOO.util.Event.addListener( prefixName + '-Button-External-LoadSettings', 'click', onExternalRadioLoadSettings);
	
	YAHOO.util.Event.addListener( prefixName + '-Field-External-Protocol', 'change', onExternalRadioProtocolChange);
}

function formatChannel(channel)
{
	var text = channel.ChannelIndex + ': ';
	if (channel.ReceiveFrequency > 0)
	{
		text += 'RX:' + channel.ReceiveFrequency.toFixed(4) + 'MHz ';
	}
	if (channel.TransmitFrequency > 0)
	{
		text += 'TX:' + channel.TransmitFrequency.toFixed(4) + 'MHz';
	}

	return text;
}

function onExternalRadioTypeChange(ev)
{
	var field = YAHOO.util.Event.getTarget(ev);
	
	enableExternalRadioParameters(field.value);
}

function onExternalSerialPortChange(ev)
{
	var field = YAHOO.util.Event.getTarget(ev);
	
	//enableExternalRadioParameters(getFieldValue( getRadioPrefixName() + '-Field-External-RadioType'));
	setSerialPortOptions( field.value );
	setOutputMode();
}

function onExternalSerialModeChange(ev)
{
	//var field = YAHOO.util.Event.getTarget(ev);
	//var fieldname = getRadioPrefixName() + '-Field-External-RadioType';
	//enableExternalRadioParameters( getFieldValue( fieldname ) );
	setOutputMode();
}

var externalProtocolSelect = null;
var externalAirlinkSpeedSelect = null;

function setSerialPortOptions( port )
{
	var name = getRadioPrefixName() + '-Field-External-RadioType';
	var prevValue = getFieldValue( name );
	clearAllFieldOptions(name);
	
	addFieldOption(name, getResource( getRadioPrefixName() + '-Resource-NoneCable' ), '0');

	if ( port == "A" )
	{
		addFieldOption(name, 'U-Link TRx', '2');
		addFieldOption(name, 'Magellan UHF', '3');
	}
	
	addFieldOption(name, 'Pacific Crest', '4');
	addFieldOption(name, 'ARF7474B EU', '5');
	addFieldOption(name, 'ARF7474A NA', '6');
	
	setFieldValue( name, prevValue );
}

function setOutputMode()
{
	var prefix = getRadioPrefixName();
	
	var port = getFieldValue( prefix + '-Field-External-SerialPort');
	enableField( prefix + '-Field-External-SerialMode', true );
	if ( port != "A" )
	{
		setFieldValue(prefix + '-Field-External-SerialMode', '232');
		disableField(prefix + '-Field-External-SerialMode');
	}
	
	var mode = getFieldValue(prefix + '-Field-External-SerialMode');
	setFieldVisible(prefix + '-Field-External-SerialRtsCts', true);
	if ( mode == "422" )
	{
		setFieldVisible(prefix + '-Field-External-SerialRtsCts', false);
	}
}

function enableExternalRadioParameters(type, pageinit)
{
	var prefix = getRadioPrefixName();
	// Init select managers
	if (externalProtocolSelect == null) externalProtocolSelect = new SelectFieldManager( prefix + '-Field-External-Protocol');
	if (externalAirlinkSpeedSelect == null) externalAirlinkSpeedSelect = new SelectFieldManager( prefix + '-Field-External-AirLinkSpeed');

	// Filter on select fields
	switch (eval(type))
	{
		case 2: // MDL
			externalProtocolSelect.setFieldOptions([0,2]); // Transparent, Dsnp
			externalAirlinkSpeedSelect.setFieldOptions([4,16,5]); // 4800, 7600, 9600
			
			if (pageinit != true)
			{
				setFieldValue( prefix + '-Field-External-SerialPort', 'A');	// Port A only
				enableField(prefix + '-Field-External-SerialPort', false);
				
				setFieldValue(prefix + '-Field-External-SerialBaudRate', 7); // 38400
				enableField(prefix + '-Field-External-SerialBaudRate', false);
				
				setFieldValue(prefix + '-Field-External-SerialMode', 422); // 422
				//enableField(prefix + '-Field-External-SerialMode', false);
				setFieldVisible(prefix + '-Field-External-SerialRtsCts', false );
			}
			break;
			
		case 3: // MGL
			if (pageinit != true)
			{
				setFieldValue(prefix + '-Field-External-SerialPort', 'A');	// Port A only
				enableField(prefix + '-Field-External-SerialPort', false);
				
				setFieldValue(prefix + '-Field-External-SerialBaudRate', 6); // 19200
				enableField(prefix + '-Field-External-SerialBaudRate', false);
				
				setFieldValue(prefix + '-Field-External-SerialMode', 422); // 422
				//enableField(prefix + '-Field-External-SerialMode', false);
				setFieldVisible(prefix + '-Field-External-SerialRtsCts', false );
			}
			break;
			
		case 4: // PDL
			externalProtocolSelect.setFieldOptions([0,1]); // Transparent, Trimtalk. Dsnp not allowed.
			externalAirlinkSpeedSelect.setFieldOptions([4,5,6]); // 4800, 9600, 19200
			
			enableField(prefix + '-Field-External-SerialPort', true); // Ports A, B, F
			enableField(prefix + '-Field-External-SerialBaudRate', true); // All rates
			//enableField(prefix + '-Field-External-SerialMode', true); // All modes
			setFieldValue(prefix + '-Field-External-SerialMode', 232);
			setFieldVisible(prefix + '-Field-External-SerialRtsCts', true );
			break;
			
		case 5: // LFE
			enableField(prefix + '-Field-External-SerialPort', true); // Ports A, B, F

			if (pageinit != true)
			{
				setFieldValue(prefix + '-Field-External-SerialBaudRate', 5); // 9600
				enableField(prefix + '-Field-External-SerialBaudRate', false);
				
				setFieldValue(prefix + '-Field-External-SerialMode', 232); // 232
				setFieldChecked( prefix + '-Field-External-SerialRtsCts', 0);
				setFieldVisible(prefix + '-Field-External-SerialRtsCts', true );
				//enableField(prefix + '-Field-External-SerialMode', false);
			}
			break;

		case 6: // LFA
			enableField(prefix + '-Field-External-SerialPort', true); // Ports A, B, F

			if (pageinit != true)
			{
				setFieldValue(prefix + '-Field-External-SerialBaudRate', 5); // 9600
				enableField(prefix + '-Field-External-SerialBaudRate', false);
				
				setFieldValue(prefix + '-Field-External-SerialMode', 232); // 232
				setFieldChecked( prefix + '-Field-External-SerialRtsCts', 0);
				setFieldVisible(prefix + '-Field-External-SerialRtsCts', true );
				//enableField(prefix + '-Field-External-SerialMode', false);
			}
			break;

		default:
			enableField(prefix + '-Field-External-SerialPort', true);
			enableField(prefix + '-Field-External-SerialBaudRate', true);
			//enableField(prefix + '-Field-External-SerialMode', true);
			break;
	}
	
	// Parameters
	setItemVisible(prefix + '-Group-External-RadioParameters', 
		type == 2 /* MDL */ ||
		type == 4 /* PDL */);
	
	// No radio?
	setFieldVisible(prefix + '-Field-External-ChannelNumber', type > 0 && type != 6); // LFA: no choice for channel
	enableSerialPortOption( prefix, type );
	setItemVisible(prefix + '-Button-External-LoadSettings', type > 0 && type != 6);  // LFA: no choice for channel
	
	// Get new port
	var port = getFieldValue(prefix + '-Field-External-SerialPort');
	if (port == 'B' || port == 'F')
	{
		setFieldValue(prefix + '-Field-External-SerialMode', 232);
		enableField(prefix + '-Field-External-SerialMode', false);
	}
	
	// Get new mode
	//var mode = getFieldValue(prefix + '-Field-External-SerialMode');
	//setFieldVisible(prefix + '-Field-External-SerialRtsCts', mode == 232);
	
	//Scrambler + FEC
	setFieldVisible(prefix + '-Field-External-Scrambler', type == 4);
	setFieldVisible(prefix + '-Field-External-FEC', type == 4);
}

function onExternalRadioProtocolChange( event )
{
	var field = YAHOO.util.Event.getTarget(event);
	setExternalAirLinkSpeed( field.value );
}

function setExternalAirLinkSpeed( protocol )
{
	var prefix = getRadioPrefixName();
	if ( protocol == '2' )//DSNP
	{
		if (externalAirlinkSpeedSelect == null) externalAirlinkSpeedSelect = new SelectFieldManager( prefix + '-Field-External-AirLinkSpeed');
		externalAirlinkSpeedSelect.setFieldOptions([4]);
	}
	else
	{
		enableExternalRadioParameters( getFieldValue( prefix + '-Field-External-RadioType' ) );
	}
}

function onExternalRadioLoadSettings()
{
	var prefix = getRadioPrefixName();
	
	// Define the callbacks for the asyncRequest
	var callbacks = {
		
		success : function (o) {

			YAHOO.log("RAW JSON DATA: " + o.responseText);

			// Process the JSON data returned from the server
			var data;
			try {
				data = YAHOO.lang.JSON.parse(o.responseText);
			}
			catch (x) {
				YAHOO.log("ERROR: JSON Parse failed!");

				// Retry
				setTimeout("onExternalRadioLoadSettings()", 5000);

				return;
			}

			YAHOO.log("PARSED DATA: " + YAHOO.lang.dump(data));

			// Get settings
			var settings = data.StatusExternalRadioChannelTable;
			if (settings == null) return;

			// Fill radio settings
			fillExternalRadioSettings(settings);
		},

		failure : function (o) {
			if (!YAHOO.util.Connect.isCallInProgress(o)) {
				YAHOO.log("ERROR: Async call failed!");
			}

		},

		timeout : 60000,
		cache : false
    };

	// Loading...
	fillExternalRadioSettings(null);
	
	// Make the call to the server for JSON data
	var url = getStatusExternalRadioChannelTableURL;
	if (simul != 1)
	{	
		url += 
			"&SerialPort=" + getFieldValue(prefix + '-Field-External-SerialPort') +
			"&RadioType=" + getFieldValue(prefix + '-Field-External-RadioType') +
			"&SerialBaudRate=" + getFieldValue(prefix + '-Field-External-SerialBaudRate') +
			"&SerialMode=" + getFieldValue(prefix + '-Field-External-SerialMode') +
			"&SerialRtsCts=" + (isFieldChecked(prefix + '-Field-External-SerialRtsCts') ? "1" : "0");
	}
	
	YAHOO.util.Connect.asyncRequest('GET', url, callbacks);
}

function fillExternalRadioSettings(settings)
{
	var prefix = getRadioPrefixName();
	clearAllFieldOptions(prefix + '-Field-External-ChannelNumber');

	if (settings == null)
	{
		addFieldOption(prefix + '-Field-External-ChannelNumber', getResource(prefix + '-Resource-Loading'), 255);
		setFieldValue(prefix + '-Field-External-ChannelNumber', 255);
	}
	else
	{
		if (settings.ChannelTable.length > 0)
		{
			for (ch in settings.ChannelTable)
			{
				var channel = settings.ChannelTable[ch];
				addFieldOption(prefix + '-Field-External-ChannelNumber', formatChannel(channel), channel.ChannelIndex);
			}
			setFieldValue(prefix + '-Field-External-ChannelNumber', settings.ChannelNumber);
		}
		else
		{
			addFieldOption(prefix + '-Field-External-ChannelNumber', getResource(prefix + '-Resource-NoFrequencies'), 255);
			setFieldValue(prefix + '-Field-External-ChannelNumber', 255);
		}

		setFieldValue(prefix + '-Field-External-Protocol', settings.Protocol);
		setFieldValue(prefix + '-Field-External-AirLinkSpeed', settings.AirLinkSpeed);
	}
}