//0 is base. All other modes are rover
var mode = 0;

function updateStatusReceiver()
{
	var callbacks = 
	{
		success:function( o )
		{
			statusSuccessCallback( o, parseStatusReceiver, "updateStatusReceiver()" );
		},
		failure: function( o )
		{
			statusFailureCallback( o, "updateStatusReceiver()" );
		},
		timeout : 10000,
		cache : false
	};
	
	YAHOO.util.Connect.asyncRequest('GET', getStatusReceiverURL, callbacks );
}

function parseStatusReceiver( data )
{
	var status = data.StatusReceiver;
	if (status == null) return;
				
	setReceiverSettings(status);
	setReceiverAntenna(status);
	setComputedPosition(status);
	setReferencePosition(status);
	setDifferentialMessages(status);
}

function setReceiverSettings( status )
{
	var text = "";
	mode = status.Settings.Mode;
	switch( status.Settings.Mode )
	{
		case 0:
		{
			text = getResource('Receiver-Resource-Base');
			break;
		}
		case 1:
		{
			text = getResource('Receiver-Resource-Rover');
			break;
		}
		case 2:
		{
			text = getResource('Receiver-Resource-BackupRtk') 
				+ ' (' + getResource('Receiver-Resource-Port') + ' ' + status.Settings.Port + ')';
			break;
		}
	}
	setItemText('Settings-Mode', text );
	
	var suffix = status.Settings.IsBaseMoving ? "Yes" : "No";
	setItemText('Settings-IsBaseMoving', getResource('Receiver-Resource-' + suffix) );
	
	suffix = status.Settings.FastRtk ? "On" : "Off";
	setItemText('Settings-FastRtk', getResource('Receiver-Resource-' + suffix) );

	setItemText('Settings-AmbiguityFixing', formatString( '{0} %', status.Settings.AmbiguityFixing ) );
			
	var dyn = new Object();
	dyn[1] = "Static";
	dyn[2] = "Quasi-static";
	dyn[3] = "Walking";
	dyn[4] = "Ship";
	dyn[5] = "Automobile";
	dyn[6] = "Aircraft";
	dyn[7] = "Unlimited";
	dyn[8] = "Adaptive";
	dyn[9] = "User-defined";
			
	text = "";
	text = getResource('Receiver-Resource-' + dyn[status.Settings.ReceiverDynamics] );
	setItemText('Settings-ReceiverDynamics', text );
		
	setItemText('Settings-RoverElevationMask', formatString( '{0} &deg;', status.Settings.RoverElevationMask ) );
	setItemText('Settings-ReferenceElevationMask', formatString( '{0} &deg;', status.Settings.ReferenceElevationMask ) );
}

function setReceiverAntenna(status)
{
	setItemText('Antenna-Receiver', status.Antenna.Receiver);
	
	var text = status.Antenna.ReferencePosition;
	switch (status.Antenna.ReferencePosition)
	{
		case 0 /* Off */: text = getResource('ReceiverPosition-Resource-L1PhaseCenter'); break;
		case 1 /* On  */: text = getResource('ReceiverPosition-Resource-SurveyPoint'); break;
		case 2 /* ARP */: text = getResource('ReceiverPosition-Resource-AntennaReferencePoint'); break;
	}	
    setItemText('Antenna-ReferencePosition', text);
	setItemTextAsDistance('Antenna-Height', status.Antenna.Height);
	
	text = status.Antenna.MeasurementType;
	switch (status.Antenna.MeasurementType)
	{
		case 0: text = getResource('ReceiverPosition-Resource-Slant'); break;
		case 1: text = getResource('ReceiverPosition-Resource-Vertical'); break;
	}	
    setItemText('Antenna-MeasurementType',text);
	
	//-- Rover Antenna Radius
    setItemTextAsDistance('Antenna-Radius',status.Antenna.Radius);
            
    //-- Rover Antenna SHMP
    setItemTextAsDistance('Antenna-ShmpOffset',status.Antenna.ShmpOffset);
    
    if (status.Antenna.Virtual == "OFF")
    {
    	text = getResource("Receiver-Resource-NoVirtualAntenna");
    } else {
    	text = status.Antenna.Virtual;
    }
    setItemText('Antenna-Virtual',text);
}

function setComputedPosition(status)
{
	var value = status.ComputedPosition.Type;
	switch (status.ComputedPosition.Type)
	{
        case 0: value = getResource('ReceiverPosition-Resource-NoPosition'); break;
        case 1: value = getResource('ReceiverPosition-Resource-Standalone'); break;
        case 2: value = getResource('ReceiverPosition-Resource-DGPS'); break;
        case 3: value = getResource('ReceiverPosition-Resource-S-DGPS'); break; 
        case 4: value = getResource('ReceiverPosition-Resource-RTKFixed'); break; 
        case 5: value = getResource('ReceiverPosition-Resource-RTKFloat'); break;
	}	
    setItemText('ComputedPosition-Type',value);
	
	setItemText('ComputedPosition-CorrectionAge', formatString( '{0} s', status.ComputedPosition.CorrectionAge ) );
	setItemTextAsLatitude('ComputedPosition-Latitude', status.ComputedPosition.Latitude);
	setItemTextAsLongitude('ComputedPosition-Longitude', status.ComputedPosition.Longitude);
	setItemTextAsDistance('ComputedPosition-Height', status.ComputedPosition.EllipsoidHeight);
	
	setItemTextAsDistance('ComputedPosition-DistanceToRefStation', status.ComputedPosition.DistanceToRefStation);
	
	setItemTextAsDistance('ComputedPosition-RmsLatitude', status.ComputedPosition.RmsLatitude);
	setItemTextAsDistance('ComputedPosition-RmsLongitude', status.ComputedPosition.RmsLongitude);
	setItemTextAsDistance('ComputedPosition-RmsHeight', status.ComputedPosition.RmsHeight);
	
	if (status.ComputedPosition.CoordinateSystemName.length > 30)
	{
		setItemText('ComputedPosition-CoordinateSystemName', status.ComputedPosition.CoordinateSystemName.substring(0,30));
	}
	else
	{
		setItemText('ComputedPosition-CoordinateSystemName', status.ComputedPosition.CoordinateSystemName);
	}
}

function setReferencePosition(status)
{
    //-- Station ID 
    setItemText('ReferencePosition-StationId',status.ReferencePosition.StationId);
            
    // Station Position (lat,long,height)
    setItemTextAsLatitude('ReferencePosition-Latitude',status.ReferencePosition.Latitude);
    setItemTextAsLongitude('ReferencePosition-Longitude',status.ReferencePosition.Longitude);
    setItemTextAsDistance('ReferencePosition-EllipsoidHeight',status.ReferencePosition.EllipsoidHeight);
            
    //-- Station Antenna
    setItemText('ReferencePosition-AntennaName',status.ReferencePosition.AntennaName);
            
    //-- Station Antenna Height
    setItemTextAsDistance('ReferencePosition-AntennaHeight',status.ReferencePosition.AntennaHeight);
}

function setDifferentialMessages(status)
{
	emptyTable('Receiver-DiffMessages-Table');
	for( i in status.DifferentialMessages)
	{
		putDifferentialMessage( status.DifferentialMessages[ i ] );
	}
}

function putDifferentialMessage(message)
{
	//Port
	var ixPattern = new RegExp('I[1-9]');
	
	if(message.Port == 'A' || message.Port == 'B' || message.Port == 'F' )
		putDiffMessage(message, buildSerialPortMsg, buildSerialPortCommType );
	else if( message.Port == 'D' && message.CommunicationType > 0)
		putDiffMessage(message, buildIntRadioPortMsg, buildSerialPortCommType );
	else if ( message.Port == 'C' )
		putDiffMessage( message, buildBluetoothPortMsg, buildBluetoothCommType );
	else if ( message.Port == 'E' && message.CommunicationType > 0)
		putDiffMessage( message, buildModemPortMsg, buildModemCommType );
	else if ( message.Port == 'P' && message.CommunicationType > 0)
		putDiffMessage( message, buildPPortMsg, buildPCommType );
	else if ( message.Port == 'Q' && message.CommunicationType > 0)
		putDiffMessage( message, buildQPortMsg, buildQCommType );
	else if ( message.Port == 'I' )
		putDiffMessage( message, buildIPortMsg, buildICommType );
	else if ( ixPattern.test( message.Port ) )
		putDiffMessage( message, buildIPortMsg, buildIxCommType );
}

function putDiffMessage(message, portFunc, msgTypeFunc )
{
	var table = 'Receiver-DiffMessages-Table';
	try
	{
		var portFuncValue = portFunc( message );
		var msgTypeFuncValue = msgTypeFunc( message );
		var buildMessageValue = buildMessage(message);
		var labelValue = null;
		
		var port = message.Port.substring(0,1);
		switch (port)
		{
		case "A":
			labelValue = getResource('Receiver-Resource-On');
		break;
		case "B":
			var value = null;
			switch (message.Status)
			{
			case 0:
				value = "Off";
			break;
			case 3:
				value = "On";	
			break;
			}
			labelValue = getResource('Receiver-Resource-' + value);
		break;
		case "F":
			var value = null;
			switch (message.Status)
			{
			case 0:
				value = "Off";
			break;
			case 3:
				value = "On";	
			break;
			}
			labelValue = getResource('Receiver-Resource-' + value);
		break;
		case "C":
			var value = null;
			switch (message.Status)
			{
			case 0:
				value = "Off";
			break;
			case 3:
				value = "On";	
			break;
			}
			labelValue = getResource('Receiver-Resource-' + value);
		break;
		case "D":
			var value = null;
			switch (message.Status)
			{
			case 0:
				value = "Off";
			break;
			case 3:
				value = "On";	
			break;
			}
			labelValue = getResource('Receiver-Resource-' + value);
		break;
		case "E":
			var value = null;
			switch (message.Status)
			{
			case 0:
				portFuncValue = null;
				msgTypeFuncValue = null;
				buildMessageValue = null;
			break;
			case 1:
				value = "Automatic";	
			break;			
			case 2:
				value = "Trying";
			break;
			case 3:
				value = "Connected";
			break;
			}
			labelValue = getResource('Receiver-Resource-' + value);
			
			if (message.Status == 1)
				labelValue += " (50 s)";
			
		break;
		case "P":
			var value = null;
			switch (message.Status)
			{
			case 0:
				portFuncValue = null;
				msgTypeFuncValue = null;
				buildMessageValue = null;
			break;
			case 1:
				value = "Automatic";
			break;				
			case 2:
				value = "Trying";
			break;
			case 3:
				value = "Connected";
			break;
			}
			labelValue = getResource('Receiver-Resource-' + value);
			
			if (message.Status == 1)
				labelValue += " (10 s)";
			
		break;
		case "Q":
			var value = null;
			switch (message.Status)
			{
			case 0:
				portFuncValue = null;
				msgTypeFuncValue = null;
				buildMessageValue = null;
			break;
			case 1:
				value = "Automatic";
			break;				
			case 2:
				value = "Trying";
			break;
			case 3:
				value = "Connected";
			break;
			}
			labelValue = getResource('Receiver-Resource-' + value);
			
			if (message.Status == 1)
				labelValue += " (10 s)";
			
		break;
		case "I":
			switch (message.CommunicationType)
			{
			case 1:
				labelValue = message.Status + " " + getResource('Receiver-Resource-Connections');
				break;
			case 2:
				var value = null;
				switch (message.Status)
				{
				case 0:
					portFuncValue = null;
					msgTypeFuncValue = null;
					buildMessageValue = null;
				break;
				case 1:
					value = "Automatic";	
				break;			
				case 2:
					value = "Trying";
				break;
				case 3:
					value = "Connected";
				break;
				}
				
				labelValue = getResource('Receiver-Resource-' + value);
				if (message.Status == 1)
					labelValue += " (10 s)";
				
				break;
			}
			
		break;
		}

		if (portFuncValue != null) {
			addTableRow(table, getResource('Receiver-Resource-Port'), portFuncValue, null );
			
			if (labelValue != null)
				addTableRow(table, getResource('Receiver-Resource-Status'), labelValue, null );
			
			addTableRow(table, getResource('Receiver-Resource-CommType'), msgTypeFuncValue, null );
			addTableRow(table, getResource('Receiver-Resource-DiffMessages'), buildMessageValue, null );
			addTableRow(table, null, '<br/>', null );
		}
	}
	catch(x)
	{
	}	
}

function buildSerialPortMsg( message )
{	
	var text =  getResource('Receiver-Resource-SerialPort') + ' ' + message.Port;
	if ( message.BaudRate != null )
	{
		text += ': ' + portSpeed[ message.BaudRate ] + 'Bds';
	}
	return text;
}
function buildIntRadioPortMsg( message )
{
	return getResource('Receiver-Resource-IntRadio') + ' ' + message.Port;
}

function buildSerialPortCommType(message)
{
	var text = '';
	switch(message.CommunicationType)
	{
		case 0:
		{
			text = 'Cable';
			break;
		}
		case 2:
		{
			text = 'U-Link TRx';
			if( message.Port == "D" )
			{
				text = "U-Link Rx";
			}
			break;
		}
		case 3:
		{
			text = "Magellan UHF";
			break;
		}
		case 4:
		{
			text = "Pacific Crest";
			break;
		}
		case 5:
		{
			text = 'ARF7474A EU';
			break;
		}
		case 6:
		{
			text = 'ARF7474A NA';
			break;
		}
	}
	
	try
	{
		if ( message.Channel != null )
			text += ': channel ' + message.Channel;
		if ( message.Frequency != null )
			text += ' (' + message.Frequency + 'Mhz)';
			
	}
	catch( x )
	{
		
	}
	return text;
}

function buildBluetoothPortMsg( message )
{
	return getResource( 'Receiver-Resource-Bluetooth' ) + ' ' + message.Port;
}
function buildBluetoothCommType(message)
{
	var text = message.CommunicationType;
	if ( message.CommunicationType == 1 )
		text = getResource( 'Receiver-Resource-Bluetooth' );
	return text;
}

function buildModemPortMsg( message )
{
	return getResource('Receiver-Resource-Modem') + ' ' + message.Port;
}
function buildModemCommType(message)
{
	switch(message.CommunicationType)
	{
		case 1: return getResource( 'Receiver-Resource-Csd' );break;
		case 2:
		{
			return getResource( 'Receiver-Resource-DirectIP') + ': ' + message.IpAddress + ':' + message.IpPort;
		}
		case 3: 
		{
			if( mode > 0 )
			{
				return getResource( 'Receiver-Resource-NtripClient' ) + ' (' + message.Mount + ')';
			}
			return getResource( 'Receiver-Resource-NtripServer' );
			break;
		}
	}
	return '';
}

function buildPPortMsg( message )
{
	return getResource('Receiver-Resource-Ethernet') + ' ' + message.Port;
}
function buildPCommType(message)
{
	if ( message.CommunicationType == 4 )
	{
		return getResource( 'Receiver-Resource-DirectIP') + ': ' + message.IpAddress + ':' + message.IpPort;
	}
	else if ( message.CommunicationType == 5 )
	{
		if ( mode > 0 )
		{
			return getResource( 'Receiver-Resource-NtripClient' ) + ' (' + message.Mount + ')';
		}
		return getResource( 'Receiver-Resource-NtripServer' );
	}
	else if ( message.CommunicationType == 7 )
	{
		return getResource( 'Receiver-Resource-EmbeddedCaster' );
	}
	
	return '';
}

function buildQPortMsg( message )
{
	return getResource('Receiver-Resource-Ethernet') + ' ' + message.Port;
}
function buildQCommType(message)
{
	if ( message.CommunicationType == 4 )
	{
		return getResource( 'Receiver-Resource-DirectIP') + ': ' + message.IpAddress + ':' + message.IpPort;
	}
	else if ( message.CommunicationType == 5 )
	{
		if ( mode > 0 )
		{
			return getResource( 'Receiver-Resource-NtripClient' ) + ' (' + message.Mount + ')';
		}
		return getResource( 'Receiver-Resource-NtripServer' );
	}
	else if ( message.CommunicationType == 7 )
	{
		return getResource( 'Receiver-Resource-EmbeddedCaster' );
	}
	
	return '';
}

function buildIPortMsg( message )
{
	return getResource( 'Receiver-Resource-Ethernet' ) + ' ' + message.Port;
}
function buildICommType(message)
{
	if (message.CommunicationType == 1 )
	{
		return getResource( 'Receiver-Resource-DirectIPServer' ) + ': ' + getResource( 'Receiver-Resource-Port' ) + ' ' + message.IpPort; 
	}	
	return message.CommuncationType;
}

function buildIxCommType(message)
{
	var text = message.CommunicationType;
	switch(message.CommunicationType)
	{
		case 1:
		{
			text = getResource( 'Receiver-Resource-EthernetServer' ) + ': ' + getResource( 'Receiver-Resource-Port' ) + ' ' + message.IpPort;
			break;
		}
		case 2:
		{
			text = getResource( 'Receiver-Resource-EthernetClient' ) + ': ' + message.IpAddress + ':' + message.IpPort;
			break;
		}
	}
	return text;
} 

function buildMessage(message)
{
	var text = "";
	try
	{
		switch(message.MessageType)
		{
			case 1: text = 'ATOM';break;
			case 2: text = 'RTCM3.x';break;
			case 3: text = 'RTCM2.3';break;
			case 4: text = 'CMR';break;
			case 5: text = 'CMR+';break;
			case 6: text = 'DBEN';break;
			case 7: text = 'TOPAZE';break;
		}
		
		if ( message.Messages != null && message.Messages.length > 0)
			text = text + ": " + message.Messages;
	}
	catch(x)
	{
	}

    return text;
}